from distutils.core import setup

setup(
	name = 'paketimiz',
	packages = ['paketimiz'],
	version = '0.1',
	description = 'Sağa sola selam veren garip bir uygulama',
	author = 'Ali GÖREN',
	author_email = 'goren.ali@yandex.com',
	url = 'https://github.com/aligoren/paketimiz',
	download_url = 'https://github.com/aligoren/paketimiz/archive/ilk.tar.gz',
	keywords = ['selam', 'naber', 'bilmemki'],
	classifiers = [],
)